Struct jrsonnet_gcmodule::ThreadedCcRef
source · pub struct ThreadedCcRef<'a, T: ?Sized> { /* private fields */ }Expand description
Wraps a borrowed reference to ThreadedCc.
The wrapper automatically takes a lock that prevents the collector from
running. This ensures that when the collector is running, there are no
borrowed references of ThreadedCc. Therefore
ThreadedCcs can be seen as temporarily immutable,
even if they might have interior mutability. The collector relies on this
for correctness.